@@ -19,6 +19,7 @@ from .wrappers.custom import dynatrace_custom_tracer as trace
 
 _LOCK = threading.Lock()
 _INSTRUMENTED_LIBS = set()
+_INSTRUMENT_LIBS_LAZY = set()
 
 INSTRUMENT_LIBS = {
     "flask": True,
@@ -33,6 +34,8 @@ INSTRUMENT_LIBS = {
     "grpc": True,
     "ruxit": True,
     "confluent_kafka": True,
+    "pysnmp": True,
+    "concurrent": True,
 }
 
 
@@ -47,6 +50,7 @@ def _on_import_wrapper(lib):
 
         path = "autodynatrace.wrappers.%s" % lib
         try:
+            logger.debug("Instrumenting imported lib '{}'".format(lib))
             imported_module = importlib.import_module(path)
             imported_module.instrument()
         except Exception:
@@ -62,13 +66,19 @@ def instrument(**instrument_libs):
 
         if lib in sys.modules:
             instrument_lib(lib)
+            _INSTRUMENTED_LIBS.add(lib)
 
         else:
             when_imported(lib)(_on_import_wrapper(lib))
-            _INSTRUMENTED_LIBS.add(lib)
+            _INSTRUMENT_LIBS_LAZY.add(lib)
 
     patched_libs = get_already_instrumented()
-    logger.info("Instrumented {}/{} libraries ({})".format(len(patched_libs), len(libs), ", ".join(patched_libs)))
+    lazy_libs = get_will_instrument()
+    logger.info(
+        "Instrumented {}/{} libraries ({}). Will instrument when imported: ({})".format(
+            len(patched_libs), len(libs), ", ".join(patched_libs), ", ".join(lazy_libs)
+        )
+    )
 
 
 def instrument_lib(lib):
@@ -99,4 +109,9 @@ def get_already_instrumented():
         return sorted(_INSTRUMENTED_LIBS)
 
 
+def get_will_instrument():
+    with _LOCK:
+        return sorted(_INSTRUMENT_LIBS_LAZY)
+
+
 instrument_all()
